// PERSISTENCE COMPONENT

//Provided Interface
// Connected to Business Component
public interface initPersistenceMechanism {
	public static synchronized PersistenceMechanism getInstance() throws PersistenceMechanismException
    public void connect() throws PersistenceMechanismException;
    public void disconnect() throws PersistenceMechanismException;
	// These methods represent the repository contructors calls inside HealthWatcherFacade
	public void initComplaintRepository();
	public void initHealthUnitRepository();
	public void initSpecialityRepository();
	public void initDiseaseType();
	public void initEmployeeRepository();
}

//Provided Interface
// Connected to Business Component
public interface transactionControlMechanism {
    public void rollbackTransaction() throws TransactionException;
    public void commitTransaction() throws TransactionException;
    public void beginTransaction() throws TransactionException;
}

//Provided Interface
// Connected to Business Component
public interface IComplaintRepository {

    public Complaint search(int complaint) throws RepositoryException, ObjectNotFoundException;

    public void update(Complaint complaint) throws RepositoryException, ObjectNotFoundException, ObjectNotValidException;

    public int insert(Complaint complaint) throws RepositoryException, ObjectAlreadyInsertedException, ObjectNotValidException;

    public boolean exists(int code) throws RepositoryException;

    public void remove(int codigo) throws RepositoryException, ObjectNotFoundException;
    
    public IteratorDsk getComplaintList() throws SearchEntryException, ObjectNotFoundException;
}

//Provided Interface
// Connected to Business Component
public interface IDiseaseRepository {

    public DiseaseType search(int code) throws RepositoryException, ObjectNotFoundException;

    public void update(DiseaseType td) throws RepositoryException, ObjectNotFoundException, ObjectNotValidException;

    public void insert(DiseaseType td)throws RepositoryException, ObjectAlreadyInsertedException, ObjectNotValidException;

    public boolean exists(int code) throws RepositoryException;
    
    public IteratorDsk getDiseaseTypeList() throws RepositoryException, ObjectNotFoundException;
}

//Provided Interface
// Connected to Business Component
public interface ISymptomRepository {

    public void insert(Symptom s) throws RepositoryException, ObjectAlreadyInsertedException,ObjectNotValidException;

    public void update(Symptom s) throws RepositoryException, ObjectNotFoundException, ObjectNotValidException;

    public boolean exists(int code) throws RepositoryException;

    public Symptom search(int code) throws RepositoryException, ObjectNotFoundException;

    public void remove(int code) throws RepositoryException, ObjectNotFoundException;
}

//Provided Interface
// Connected to Business Component
public interface IEmployeeRepository {

    public Employee search(String login) throws ObjectNotFoundException;

    public void update(Employee employee) throws ObjectNotFoundException, ObjectNotValidException;

    public void insert(Employee employee) throws InsertEntryException;

    public boolean exists(String login);

    public void remove(String login) throws ObjectNotFoundException;
}

//Provided Interface
// Connected to Business Component
public interface IHealthUnitRepository {

    public void update(HealthUnit us) throws RepositoryException, ObjectNotFoundException,ObjectNotValidException;
    
    public boolean exists(int num) throws RepositoryException;
    
    public IteratorDsk getHealthUnitList() throws RepositoryException, ObjectNotFoundException;
    
    public IteratorDsk getPartialHealthUnitList() throws RepositoryException, ObjectNotFoundException;
    
    public IteratorDsk getHealthUnitListBySpeciality(int codEspecialidade) throws RepositoryException, ObjectNotFoundException;
    
    public void insert(HealthUnit us)  throws RepositoryException, ObjectAlreadyInsertedException,ObjectNotValidException;
    
    public HealthUnit search(int code) throws RepositoryException, ObjectNotFoundException;
    
    public void remove(int code) throws RepositoryException, ObjectNotFoundException;
}

//Provided Interface
// Connected to Business Component
public interface ISpecialityRepository {

    public void update(MedicalSpeciality esp) throws RepositoryException, ObjectNotFoundException,ObjectNotValidException;
    
    public boolean exists(int num) throws RepositoryException;
    
    public IteratorDsk getSpecialityList() throws RepositoryException, ObjectNotFoundException;
    
    public void insert(MedicalSpeciality esp) throws RepositoryException, ObjectAlreadyInsertedException,ObjectNotValidException;
    
    public MedicalSpeciality search(int codigo) throws RepositoryException, ObjectNotFoundException;
    
    public void remove(int codigo) throws RepositoryException, ObjectNotFoundException;
}